<?php

class Trail {
    protected $_data = array();
    protected $_konst = array (
        0 => array(
            'dry' => 0.83,
            '1m' => 0.42,
            '2m' => 0.27,
            'ice' => 0.06,
        ),
        1 => array(
            'dry' => 0.8,
            '1m' => 0.3,
            '2m' => 0.15,
            'ice' => 0.02,
        ),
        3 => array(
            'dry' => 0.75,
            '1m' => 0.2,
            '2m' => 0.02,
            'ice' => 0.01,
        ),
        5 => array(
            'dry' => 0.9,
            '1m' => 0.4,
            '2m' => 0.22,
            'ice' => 0.06,
        ),
        7 => array(
            'dry' => 0.85,
            '1m' => 0.27,
            '2m' => 0.12,
            'ice' => 0.02,
        ),
        9 => array(
            'dry' => 0.8,
            '1m' => 0.07,
            '2m' => 0.03,
            'ice' => 0.02,
        ),
    );
    
    public function setData($post) {
        $this->_data = array(
            'mass' => $post['mass'],
            'koef' => $post['koef'],
            'glass' => $post['glass'],
            'depth' => $post['depth'],
            'skew' => $post['skew'],
            'wind' => $post['wind'],
            'delay' => $post['delay'],
            'break_koef' => $post['break_koef'],
            'whole_break' => $post['whole_break'],
        );
    }
    
    public function processTrail() {
        $d = $this->_data;
        $depth = $d['depth'];

        foreach ($this->_konst as $dezen=>$koefs) {
            if ($depth <= $dezen) break;
        }
        
        $pow = $this->_getMinPower($koefs['dry']);

        $line = array();
        for ($v=80; $v>=0; $v--) {
            $pwr = $pow + (1.202 * $d['glass'] * $d['koef'] * (($v - $d['wind']) * abs($v - $d['wind'])) / (2 * 3.6 * 3.6)) + 9.81 * (0.017 + 0.0000003 * $v * $v) * $d['mass'] - 40 * $d['break_koef'] + $d['mass'] * 9.81 * $d['skew'] / 100;
            $trail = ($v * $v / (3.6 * 3.6)) / (2 * $pwr / $d['mass']);
            $line[$v] = $this->_getTrail($v, $pow);
        }
        $this->_data['_line'] = $line;
        $this->_data['_table'] = array (
            130 => array(
                'dry' => round($this->_getTrail(130, $this->_getMinPower($koefs['dry'])),2),
                '1m' => round($this->_getTrail(130, $this->_getMinPower($koefs['1m'])),2),
                '2m' => round($this->_getTrail(130, $this->_getMinPower($koefs['2m'])),2),
                'ice' => round($this->_getTrail(130, $this->_getMinPower($koefs['ice'])),2),
            ),
            90 => array(
                'dry' => round($this->_getTrail(90, $this->_getMinPower($koefs['dry'])),2),
                '1m' => round($this->_getTrail(90, $this->_getMinPower($koefs['1m'])),2),
                '2m' => round($this->_getTrail(90, $this->_getMinPower($koefs['2m'])),2),
                'ice' => round($this->_getTrail(90, $this->_getMinPower($koefs['ice'])),2),
            ),
            50 => array(
                'dry' => round($this->_getTrail(50, $this->_getMinPower($koefs['dry'])),2),
                '1m' => round($this->_getTrail(50, $this->_getMinPower($koefs['1m'])),2),
                '2m' => round($this->_getTrail(50, $this->_getMinPower($koefs['2m'])),2),
                'ice' => round($this->_getTrail(50, $this->_getMinPower($koefs['ice'])),2),
            ),
        );
        $this->_data['_result'] = $this->_getTrail(80, $this->_getMinPower($koefs['dry']));
    }
    
    protected function _getMinPower($koef) {
        $pow = 9.81 * $koef * $this->_data['mass'];
        $pow = min($pow, $this->_data['whole_break']);   
        return $pow;
    }
    
    protected function _getTrail($v, $pow) {
        $d = $this->_data;
        $pwr = $pow + (1.202 * $d['glass'] * $d['koef'] * (($v - $d['wind']) * abs($v - $d['wind'])) / (2 * 3.6 * 3.6)) + 9.81 * (0.017 + 0.0000003 * $v * $v) * $d['mass'] - 40 * $d['break_koef'] + $d['mass'] * 9.81 * $d['skew'] / 100;
        $trail = ($v * $v / (3.6 * 3.6)) / (2 * $pwr / $d['mass']);
        $trail = $trail + $v / 3.6 * $d['delay'];
        return $trail;
    }
    
    public function getValue($variable) {
        return $this->_data[$variable];
    }
    
}

$trail = new Trail;
if (isset($_POST['op']) && $_POST['op'] == 'trail') {
    $trail->setData($_POST);
    $trail->processTrail();
?>
<div class="well clearfix">
    <h2>Brzdná dráha <?php echo round($trail->getValue('_result'), 2)?>m</h2>
    <div class="col-md-12 chart">
        <div id="chart_trail"></div>
    </div>
<?php $line = $trail->getValue('_line'); ?>
<script>
    function drawTrailChart() {
      var data = new google.visualization.DataTable();
      data.addColumn('number', 'Brzdná dráha');
      data.addColumn('number', 'Rychlost');

      data.addRows([
      <?php foreach ($line as $v => $t) {
            echo "[" . round($t,1) . ", $v]";
            if ($v != 0) echo ', ';
        }
      ?>
      ]);

      var options = {
        title: 'Brzdná dráha na suchu',
        height: 350,
        hAxis: {
        title: 'Brzdná dráha (m)',
          direction: -1
        },
        vAxis: {
            title: 'Rychlost (km/h)',
            minValue: 0,
        },
      };

      var chart = new google.visualization.LineChart(document.getElementById('chart_trail'));
      chart.draw(data, options);
    }
    drawTrailChart();
</script>
    <div  class="col-xs-12 col-md-12">
        <?php $t = $trail->getValue('_table'); ?>
        
        <table class="table table-bordered table-condensed table-striped">
        <thead><th></th><th>Sucho</th><th>1mm vody</th><th>2mm vody</th><th>Náledí</th></thead>
        <tbody>
        <tr><td>130 km.h<sup>-1</sup></td><td><?php echo $t[130]['dry'] ?> m</td><td><?php echo $t[130]['1m'] ?> m</td><td><?php echo $t[130]['2m'] ?> m</td><td><?php echo $t[130]['ice'] ?> m</td></tr>
        <tr><td>90 km.h<sup>-1</sup></td><td><?php echo $t[90]['dry'] ?> m</td><td><?php echo $t[90]['1m'] ?> m</td><td><?php echo $t[90]['2m'] ?> m</td><td><?php echo $t[90]['ice'] ?> m</td></tr>
        <tr><td>50 km.h<sup>-1</sup></td><td><?php echo $t[50]['dry'] ?> m</td><td><?php echo $t[50]['1m'] ?> m</td><td><?php echo $t[50]['2m'] ?> m</td><td><?php echo $t[50]['ice'] ?> m</td></tr>
        </tbody>
        </table>
    </div>
</div>
<?php } ?>